# BayesFlux

**BayesFlux** is a JAX Python package that provides Fast Linear algebra sUbspace eXtraction for Bayesian inverse problems build off [randLAX](https://github.com/joshuawchen/randLAX).

## Features

- Active Subspace for parameter dimension reduction
- Informative Output Subspace  for data dimension reduction

## Installation

You can install the package using pip:

```bash
pip install bayesflux
